% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/objects.R
\name{xy_rect}
\alias{xy_rect}
\title{Rectangular XY Plane Object}
\usage{
xy_rect(
  x = 0,
  y = 0,
  z = 0,
  xwidth = 1,
  ywidth = 1,
  material = diffuse(),
  angle = c(0, 0, 0),
  order_rotation = c(1, 2, 3),
  flipped = FALSE,
  scale = c(1, 1, 1)
)
}
\arguments{
\item{x}{Default `0`. x-coordinate of the center of the rectangle.}

\item{y}{Default `0`. x-coordinate of the center of the rectangle.}

\item{z}{Default `0`. z-coordinate of the center of the rectangle.}

\item{xwidth}{Default `1`. x-width of the rectangle.}

\item{ywidth}{Default `1`. y-width of the rectangle.}

\item{material}{Default  \code{\link{diffuse}}.The material, called from one of the material 
functions \code{\link{diffuse}}, \code{\link{metal}}, or \code{\link{dielectric}}.}

\item{angle}{Default `c(0, 0, 0)`. Angle of rotation around the x, y, and z axes, applied in the order specified in `order_rotation`.}

\item{order_rotation}{Default `c(1, 2, 3)`. The order to apply the rotations, referring to "x", "y", and "z".}

\item{flipped}{Default `FALSE`. Whether to flip the normals.}

\item{scale}{Default `c(1, 1, 1)`. Scale transformation in the x, y, and z directions. If this is a single value,
number, the object will be scaled uniformly.
Note: emissive objects may not currently function correctly when scaled.}
}
\value{
Single row of a tibble describing the XY plane in the scene.
}
\description{
Rectangular XY Plane Object
}
\examples{
#Generate a purple rectangle in the cornell box.
\donttest{
generate_cornell() \%>\%
  add_object(xy_rect(x = 555/2, y = 100, z = 555/2, xwidth = 200, ywidth = 200,
             material = diffuse(color = "purple"))) \%>\%
  render_scene(lookfrom = c(278, 278, -800), lookat = c(278, 278, 0), fov = 40, 
               ambient_light = FALSE, samples = 400, parallel = TRUE, clamp_value = 5)
}

#Generate a gold plane in the cornell box
\donttest{
generate_cornell() \%>\%
  add_object(xy_rect(x = 555/2, y = 100, z = 555/2, 
                     xwidth = 200, ywidth = 200, angle = c(0, 30, 0),
                     material = metal(color = "gold"))) \%>\%
  render_scene(lookfrom = c(278, 278, -800) ,lookat = c(278, 278, 0), fov = 40, 
               ambient_light = FALSE, samples = 400, parallel = TRUE, clamp_value = 5)
}
}
